@@ -6,8 +6,48 @@ use warnings;
 use Carp qw(croak);
 use List::Util qw(sum);
 use Statistics::Descriptive;
+use vars qw($VERSION);
+$VERSION = 0.031;
 
-our $VERSION = '0.03';
+=pod
+
+=head1 NAME
+
+Statistics::FisherPitman - Randomization-based alternative to one-way independent groups ANOVA; unequal variances okay
+
+=head1 SYNOPSIS
+
+ use Statistics::FisherPitman 0.031;
+
+ my @dat1 = (qw/12 12 14 15 12 11 15/);
+ my @dat2 = (qw/13 14 18 19 22 21 26/);
+
+ my $fishpit = Statistics::FisherPitman->new();
+ $fishpit->load({d1 => \@dat1, d2 => \@dat2});
+
+ # Oh, more data just came in:
+ my @dat3 = (qw/11 7 7 2 19 19/);
+ $fishpit->add({d3 => \@dat3});
+
+ my $T = $fishpit->t_value();
+ # now go to monte carlo to get a p for your T
+
+ # or get a t_value and p_value in one by randomization test:
+ $fishpit->p_value(resamplings => 1000)->dump(title => "A test");
+
+=head1 DESCRIPTION
+
+Tests for a difference between independent samples. It is commonly recommended as an alternative to the oneway independent groups ANOVA when variances are unequal, as its test-statistic, I<T>, is not dependent on an estimate of variance. As a randomization test, it is "distribution-free", with the probability of obtaining the observed value of I<T> being derived from the data themselves.
+
+=head1 METHODS
+
+=head2 new
+
+ $fishpit = Statistics::FisherPitman->new()
+
+Class constructor; expects nothing.
+
+=cut
 
 #-----------------------------------------------------------------------
 sub new {
@@ -20,6 +60,22 @@ sub new {
     return $self;
 }
 
+=head2 load
+
+ $fishpit->load('aname', @data1)
+ $fishpit->load('aname', \@data1)
+ $fishpit->load({'aname' => \@data1, 'another_name' => \@data2})
+
+I<Alias>: C<load_data>
+
+Accepts either (1) a single C<name =E<gt> value> pair of a sample name, and a list (referenced or not) of data; or (2) a hash reference of named array references of data. The data are loaded into the class object by name, within a hash named C<data>, as L<Statistics::Descriptive::Full|Statistics::Descriptive> objects. So you can easily get at any descriptives for the groups you've loaded - e.g., $fishpit->{'data'}->{'aname'}->mean() - or you could get at the data again by going $fishpit->{'data'}->{'aname'}->get_data(); and so on. The names of the data are up to you.
+
+Each call L<unload|unload>s any previous loads.
+
+Returns the Statistics::FisherPitman object.
+
+=cut
+
 #-----------------------------------------------------------------------
 sub load {
 #-----------------------------------------------------------------------        
@@ -27,6 +83,20 @@ sub load {
     $self->unload();
     $self->add(@_);
 }
+*load_data = \&load; # Alias
+
+
+=head2 add
+
+ $fishpit->add('another_name', @data2)
+ $fishpit->add('another_name', \@data2)
+ $fishpit->add({'another_name' => \@data2})
+
+I<Alias>: C<add_data>
+
+Same as L<load|load> except that any previous loads are not L<unload|unload>ed.
+
+=cut
 
 #-----------------------------------------------------------------------
 sub add {
@@ -48,6 +118,15 @@ sub add {
        $self->{'data'}->{$sample_name}->add_data(@{$sample_data});
     }
 }
+*add_data = \&add; # Alias
+
+=head2 unload
+
+ $fishpit->unload();
+
+Empties all cached data and calculations upon them, ensuring these will not be used for testing. This will be automatically called with each new load, but, to take care of any development, it could be good practice to call it yourself whenever switching from one dataset for testing to another.
+
+=cut
 
 #-----------------------------------------------------------------------        
 sub unload {
@@ -56,9 +135,27 @@ sub unload {
     $self->{'data'} = {};
     $self->{$_} = undef foreach qw/df_t df_e f_value chi_value p_value ss_t ss_e ms_t ms_e conf_int/;
 }
-  
+
+=head2 t_value
+
+ $fishpit->t_value()
+
+Returns a Fisher-Pitman T-value for the loaded data, and lumps the value into the class object for the key I<t_value>.
+
+I<T> is calculated as follows:
+
+=for html <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<i>g</i><br>&nbsp;<i>T</i> = &nbsp;SUM&nbsp;&nbsp;<i>n</i><sub><i>i</i></sub>&nbsp;<i>x<sub><i>i</i></sub>&sup2;</i></sup><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<i>i</i> = 1</p>
+
+which pertains to the I<n>umber of observations in each I<i> of I<g> samples, and
+
+=for html <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<i>n</i><sub><i>i</i></sub><br>&nbsp;<i>x</i><sub><i>i</i></sub> = &nbsp;1/<i>n</i><sub><i>i</i></sub>&nbsp;SUM&nbsp;&nbsp;<i>x</i><sub><i>ij</i></sub><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<i>j</i> = 1</p>
+
+(for each I<j> observation in the I<i> sample).
+
+=cut
+
 #-----------------------------------------------------------------------        
-sub test {
+sub t_value {
 #-----------------------------------------------------------------------        
     my ($self, %args) = @_;
     my %data = ref $args{'data'} eq 'HASH' ? %{$args{'data'}} : ref $self->{'data'} eq 'HASH' ? %{$self->{'data'}} : croak 'No reference to a hash of data for performing ANOVA';
@@ -70,13 +167,50 @@ sub test {
        push @dat, $data{$_}->get_data;
     }
 
+    my $T = _get_T(\%orig);
+    $self->{'t_value'} = $T;
+    
+    return $T;
+}
+
+=head2 p_value
+
+ $fishpit->p_value(resamplings => 'non-negative number')
+
+I<Alias>: test
+
+With a positive value for I<resamplings>, the loaded data will be shuffled so many times, and the T-value calculated for each resampling. The proportion of T-values in these resamplings that are greater than I<or equal to> the T-value of the original data, as loaded, is the I<p_value> for basing significance considerations upon.
+
+Randomization test is simply based on pooling all the data and, for each resampling, giving them a Fisher-Yates shuffle, and distributing them to so many groups, of so many sample-sizes, as in the original dataset.
+
+The class object is fed the values for C<t_value> and C<p_value>. Confidence interval (95%) of the true proportion (p-value) is also calculated and stored as a two-element array named C<conf_int>. The method returns only itself. So you can get at these values thus:
+
+ print "T = $fishpit->{'t_value'}, p = $fishpit->{'p_value'}\n";
+ print '95% confidence interval for the proportion of Ts greater than or equal to the observed value ranges from ';
+ print "$fishpit->{'conf_int'}->[0] to $fishpit->{'conf_int'}->[1].\n";
+
+=cut
+  
+#-----------------------------------------------------------------------        
+sub p_value {
+#-----------------------------------------------------------------------        
+    my ($self, %args) = @_;
+    my %data = ref $args{'data'} eq 'HASH' ? %{$args{'data'}} : ref $self->{'data'} eq 'HASH' ? %{$self->{'data'}} : croak 'No reference to a hash of data for performing ANOVA';
+    
+    my (%lens, @dat, %orig) = ();
+    foreach (keys %data) {
+       $orig{$_} = [$data{$_}->get_data];
+       push @dat, $data{$_}->get_data;
+       $lens{$_} = $data{$_}->count or croak 'Empty data sent to Fisher-Pitman test';
+    }
+
     my $T = _get_T(\%orig);
     $self->{'t_value'} = $T;
 
     my $resamplings = $args{'resamplings'} || return $self; 
 
-    my $n_gteq = 0;
-    my ($name, @ari, @perm, %rands) = ();
+    my ($n_gteq, $name, @ari, @perm, %rands) = (0);
+    
     foreach (1 .. $resamplings) {
         fy_shuffle(\@dat);
         @perm = @dat;
@@ -94,7 +228,16 @@ sub test {
     $self->{'p_value'} = $p;
     $self->{'conf_int'} = _conf_int($n_gteq, $resamplings);
     return $self;
-} 
+}
+*test = \&p_value; # Alias
+
+=head2 dump
+
+ $fishpit->dump(title => 'A test of something', conf_int => 1|0, precision_p => integer)
+
+Prints a line to STDOUT of the form I<T = t_value, p = p_value>. Above this string, a title can also be printed, by giving a value to the optional I<title> argument. The 95% confidence interval, and the precision of the p-value(s), can also be optionally dumped, as above. Ends with a line-break, i.e., "\n".
+
+=cut
 
 #-----------------------------------------------------------------------        
 sub dump {
@@ -105,6 +248,14 @@ sub dump {
     print "\n";
 }
 
+=head2 string
+
+ $fishpit->string(conf_int => 1|0, precision_p => integer)
+
+Returns a line of the form I<T = t_value, p = p_value>, to the precision specified (if any), and, optionally, with the confidence-interval for the p-value appended.
+
+=cut
+
 #-----------------------------------------------------------------------        
 sub string {
 #-----------------------------------------------------------------------        
@@ -113,13 +264,13 @@ sub string {
     $str .= "T = $self->{'t_value'}";
     if (defined $self->{'p_value'}) {
         $str .= ', p = ';
-        $str .= $args{'p_precision'} ? sprintf('%.' . $args{'p_precision'} . 'f', $self->{'p_value'}) : $self->{'p_value'};
+        $str .= $args{'precision_p'} ? sprintf('%.' . $args{'precision_p'} . 'f', $self->{'p_value'}) : $self->{'p_value'};
         if ($args{'conf_int'}) {
             $str .= " (95% CI: ";
-            if ($args{'p_precision'}) {
-                $str .= sprintf('%.' . $args{'p_precision'} . 'f', $self->{'conf_int'}->[0]);
+            if ($args{'precision_p'}) {
+                $str .= sprintf('%.' . $args{'precision_p'} . 'f', $self->{'conf_int'}->[0]);
                 $str .= ', ';
-                $str .= sprintf('%.' . $args{'p_precision'} . 'f', $self->{'conf_int'}->[1]);
+                $str .= sprintf('%.' . $args{'precision_p'} . 'f', $self->{'conf_int'}->[1]);
             }
             else {
                 $str .= join(', ', @{$self->{'conf_int'}});
@@ -150,7 +301,7 @@ sub _conf_int {
     return [$lo, $hi];
 }
 
-sub fy_shuffle { # fisher-yates shuffle, ta to Perl FAQ 4
+sub fy_shuffle { # fisher-yates shuffle, via Perl FAQ 4
 	my ($list) = @_;
 	my $i;
 	for ($i = @$list; --$i; ) {
@@ -160,111 +311,9 @@ sub fy_shuffle { # fisher-yates shuffle, ta to Perl FAQ 4
 	}
 }
 
-# Aliases:
-*load_data = \&load;
-*add_data = \&add;
-
 1;
 __END__
 
-=head1 NAME
-
-Statistics::FisherPitman - Randomization-based alternative to one-way independent groups ANOVA; unequal variances okay
-
-=head1 SYNOPSIS
-
- use Statistics::FisherPitman 0.03;
-
- my @dat1 = (qw/12 12 14 15 12 11 15/);
- my @dat2 = (qw/13 14 18 19 22 21 26/);
-
- my $fishpit = Statistics::FisherPitman->new();
- $fishpit->load({d1 => \@dat1, d2 => \@dat2});
-
- # Oh, more data just came in:
- my @dat3 = (qw/11 7 7 2 19 19/);
- $fishpit->add({d3 => \@dat3});
-
- $fishpit->test(resamplings => 1000)->dump(title => "A test");
-
-=head1 DESCRIPTION
-
-Tests for a difference between independent samples. It is commonly recommended as an alternative to the oneway independent groups ANOVA when variances are unequal, as its test-statistic, I<T>, is not dependent on an estimate of variance. As a randomization test, it is "distribution-free", with the probability of obtaining the observed value of I<T> being derived from the data themselves.
-
-=head1 METHODS
-
-=head2 new
-
- $fishpit = Statistics::FisherPitman->new()
-
-Class constructor; expects nothing.
-
-=head2 load
-
- $fishpit->load('aname', @data1)
- $fishpit->load('aname', \@data1)
- $fishpit->load({'aname' => \@data1, 'another_name' => \@data2})
-
-I<Alias>: C<load_data>
-
-Accepts either (1) a single C<name =E<gt> value> pair of a sample name, and a list (referenced or not) of data; or (2) a hash reference of named array references of data. The data are loaded into the class object by name, within a hash named C<data>, as L<Statistics::Descriptive::Full|Statistics::Descriptive> objects. So you can easily get at any descriptives for the groups you've loaded - e.g., $fishpit->{'data'}->{'aname'}->mean() - or you could get at the data again by going $fishpit->{'data'}->{'aname'}->get_data(); and so on. The names of the data are up to you.
-
-Each call L<unload|unload>s any previous loads.
-
-Returns the Statistics::FisherPitman object.
-
-=head2 add
-
- $fishpit->add('another_name', @data2)
- $fishpit->add('another_name', \@data2)
- $fishpit->add({'another_name' => \@data2})
-
-I<Alias>: C<add_data>
-
-Same as L<load|load> except that any previous loads are not L<unload|unload>ed.
-
-=head2 unload
-
- $fishpit->unload();
-
-Empties all cached data and calculations upon them, ensuring these will not be used for testing. This will be automatically called with each new load, but, to take care of any development, it could be good practice to call it yourself whenever switching from one dataset for testing to another.
-
-=head2 test
-
- $fishpit->test(resamplings => 'non-negative number')
-
-Calculates the T-statistic for the loaded data, and, if you send a positive value for I<resamplings>, it is taken that you want a randomization test, in which case the loaded data will be shuffled so many times, and the T-value calculated for each resampling. The proportion of T-values in these resamplings that are greater than I<or equal to> the T-value of the original data, as loaded, is the I<p_value> for basing significance considerations upon.
-
-I<T> is calculated as follows:
-
-=for html <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<i>g</i><br>&nbsp;<i>T</i> = &nbsp;SUM&nbsp;&nbsp;<i>n</i><sub><i>i</i></sub>&nbsp;<i>x<sub><i>i</i></sub>&sup2;</i></sup><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<i>i</i> = 1</p>
-
-which pertains to the I<n>umber of observations in each I<i> of I<g> samples, and
-
-=for html <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<i>n</i><sub><i>i</i></sub><br>&nbsp;<i>x</i><sub><i>i</i></sub> = &nbsp;1/<i>n</i><sub><i>i</i></sub>&nbsp;SUM&nbsp;&nbsp;<i>x</i><sub><i>ij</i></sub><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<i>j</i> = 1</p>
-
-(for each I<j> observation in the I<i> sample).
-
-Randomization test is simply based on pooling all the data and, for each resampling, giving them a Fisher-Yates shuffle, and distributing them to so many groups, of so many sample-sizes, as in the original dataset.
-
-The class object is fed with the attributes I<t_value> and I<p_value>, and returns only itself. Confidence interval (95%) of the true proportion (p-value) is also calculated and stored as a two-element array named I<conf_int>. So you can get at these values thus:
-
- print "T = $fishpit->{'t_value'}, p = $fishpit->{'p_value'}\n";
- print '95% confidence interval for the proportion of Ts greater than or equal to the observed value ranges from ';
- print "$fishpit->{'conf_int'}->[0] to $fishpit->{'conf_int'}->[1].\n";
-
-=head2 dump
-
- $fishpit->dump(title => 'A test of something', conf_int => 1|0, p_precision => integer)
-
-Prints a line to STDOUT of the form I<T = t_value, p = p_value>. Above this string, a title can also be printed, by giving a value to the optional I<title> argument. The 95% confidence interval, and the precision of the p-value(s), can also be optionally dumped, as above. Ends with a line-break, i.e., "\n".
-
-=head2 string
-
- $fishpit->string(conf_int => 1|0, p_precision => integer)
-
-Returns a line of the form I<T = t_value, p = p_value>, to the precision specified (if any), and, optionally, with the confidence-interval for the p-value appended.
-
 =head1 EXAMPLE
 
 This example is taken from Berry & Mielke (2002); see C<ex/fishpit.pl> in the installation dist for implementation. The following (real) data are lead (Pb) values (in mg/kg) of soil samples from two districts in New Orleans, one from school grounds, another from surrounding streets. Was there a significant difference in lead levels between the samples? The variances were determined to be unequal, and the Fisher-Pitman test put to the question. As there were over 100 billion possible permutations of the data, a large number of resamplings was used: 10 million. 
@@ -288,7 +337,7 @@ The following shows how the test would be performed with the present module; usi
  my $fishpit = Statistics::FisherPitman->new();
  $fishpit->load_data($data);
  $| = 1; # this could take a little while
- $fishpit->test(resamplings => 10000)->dump(conf_int => 1, p_precision => 3);
+ $fishpit->test(resamplings => 10000)->dump(conf_int => 1, precision_p => 3);
  # This prints, e.g.: T = 56062045.0525, p = 0.014 (95% CI: 0.011, 0.016)
 
 Hence a difference is indicated, which can be identified from the means. The data being cached as L<Statistics::Descriptive|Statistics::Descriptive> objects (see L<load|load>), the means can be got at thus:
@@ -318,25 +367,17 @@ Randomization procedure can always be improved.
 
 =head1 REVISION HISTORY
 
-=over 4
-
-=item v 0.01
-
-June 2008: Initital release via PAUSE. 
-
-=back
-
-See CHANGES in installation distribution for subsequent updates.
+See CHANGES in installation distribution.
 
 =head1 AUTHOR/LICENSE
 
 =over 4
 
-=item Copyright (c) 2006-2008 Roderick Garton
+=item Copyright (c) 2006-2009 Roderick Garton
 
 rgarton AT cpan DOT org
 
-This program is free software. This module is free software. It may be used, redistributed and/or modified under the stame terms as Perl-5.6.1 (or later) (see L<http://www.perl.com/perl/misc/Artistic.html>).
+This program is free software. It may be used, redistributed and/or modified under the same terms as Perl-5.6.1 (or later) (see L<http://www.perl.com/perl/misc/Artistic.html>).
 
 =item Disclaimer
 
